#[repr(u8)]pub enum Waksrc {
WAKSRC_0 = 0,
WAKSRC_1 = 1,
}Variants
WAKSRC_0 = 0
FLEXCAN uses the unfiltered FLEXCAN_RX input to detect recessive to dominant edges on the CAN bus.
WAKSRC_1 = 1
FLEXCAN uses the filtered FLEXCAN_RX input to detect recessive to dominant edges on the CAN bus
Implementations