#[repr(u8)]pub enum Wrnen {
WRNEN_0 = 0,
WRNEN_1 = 1,
}Variants
WRNEN_0 = 0
TWRN_INT and RWRN_INT bits are zero, independent of the values in the error counters.
WRNEN_1 = 1
TWRN_INT and RWRN_INT bits are set when the respective error counter transition from <96 to >= 96.
Implementations